pub struct Colors<'a, SD: SummaryData<DI>, DI> { /* private fields */ }Expand description
contains the hues, the markers signifying which tag belongs to which group, the maximun kmer count and the average kmer count
Implementations
Sourceimpl<'a, SD: SummaryData<DI> + Debug, DI> Colors<'a, SD, DI>
impl<'a, SD: SummaryData<DI> + Debug, DI> Colors<'a, SD, DI>
Sourcepub fn new<'b: 'a, K: Kmer>(
graph: &DebruijnGraph<K, SD>,
summary_config: &SummaryConfig,
color_mode: ColorMode<'b>,
) -> Self
pub fn new<'b: 'a, K: Kmer>( graph: &DebruijnGraph<K, SD>, summary_config: &SummaryConfig, color_mode: ColorMode<'b>, ) -> Self
Creates a new Colors<SD>.
Sourcepub fn node_color_dot(
&self,
data: &SD,
summary_config: &SummaryConfig,
outline: bool,
) -> String
pub fn node_color_dot( &self, data: &SD, summary_config: &SummaryConfig, outline: bool, ) -> String
get the color for a node in a HSV format
Sourcepub fn hue_json(&self, data: &SD, summary_config: &SummaryConfig) -> i32
pub fn hue_json(&self, data: &SD, summary_config: &SummaryConfig) -> i32
get the hue for hsl color in json
Sourcepub fn edge_width(&self, edge_mult: u32) -> f32
pub fn edge_width(&self, edge_mult: u32) -> f32
get the edge width based on the edge multiplicity
pub fn id_group_ids(&self) -> Option<&HashMap<ID, ID>>