pub fn get_min_max<I: Debug, F, II, N>(
iter_struct: &I,
iter_value: &F,
) -> (Option<(N, N)>, Option<N>, Option<N>)Expand description
get the minimum and maximum value of an iterator, and if they are three times as small/large as the next smallest/largest item, also return the latter filters for -inf and inf with floats